@@ -13,15 +13,14 @@ func (vx *Vaxis) applyQuirks() {
 	case strings.HasPrefix(id, "kitty"):
 		log.Debug("kitty identified. applying quirks")
 		vx.caps.noZWJ = true
+	case id == "tmux 3.4":
+		// tmux 3.4 has unicode support, but doesn't advertise via 2027
+		vx.caps.unicodeCore = true
+
 	}
 
-	// TODO: remove this when asciinema supports ':' delimiters in RGB
 	if os.Getenv("ASCIINEMA_REC") != "" {
-		fgIndexSet = strings.ReplaceAll(fgIndexSet, ":", ";")
-		fgRGBSet = strings.ReplaceAll(fgRGBSet, ":", ";")
-		bgIndexSet = strings.ReplaceAll(bgIndexSet, ":", ";")
-		bgRGBSet = strings.ReplaceAll(bgRGBSet, ":", ";")
-		// Asciinema also doesn't support any advanced image protocols
+		// Asciinema doesn't support any advanced image protocols
 		vx.graphicsProtocol = halfBlock
 	}
 	if os.Getenv("VAXIS_FORCE_LEGACY_SGR") != "" {
